@@ -4,12 +4,11 @@ from typing import Dict
 
 from asgiref.sync import async_to_sync
 from django.apps import apps
+from django.conf import settings
 from django.urls import reverse
+from gcp_pilot.pubsub import CloudSubscriber, CloudPublisher
 from gcp_pilot.scheduler import CloudScheduler
 from gcp_pilot.tasks import CloudTasks
-from gcp_pilot.pubsub import CloudSubscriber, CloudPublisher
-
-import settings
 
 
 class Task(ABC):
@@ -24,13 +23,13 @@ class Task(ABC):
         status = 200
         return output, status
 
-    async def delay(self, **kwargs):
+    def delay(self, **kwargs):
         if getattr(settings, 'EAGER_TASKS', False):
             return self.run(**kwargs)
 
         payload = kwargs
 
-        return await self.__client.push(
+        return async_to_sync(self.__client.push)(
             task_name=self.name(),
             queue_name=self.queue,
             url=self.url(),
@@ -59,13 +58,13 @@ class Task(ABC):
 class PeriodicTask(Task, ABC):
     run_every = None
 
-    async def delay(self, **kwargs):
+    def delay(self, **kwargs):
         if getattr(settings, 'EAGER_TASKS', False):
             return self.run(**kwargs)
 
         payload = kwargs
 
-        return await self.__client.put(
+        return async_to_sync(self.__client.put)(
             name=self.schedule_name,
             url=self.url(),
             payload=json.dumps(payload),
@@ -93,11 +92,11 @@ class PubSubTaskMixin:
 
 class SubscriberTask(PubSubTaskMixin, Task, ABC):
     @abstractmethod
-    def run(self, message, metadata):
+    def run(self, message, attributes):
         raise NotImplementedError()
 
-    async def delay(self, **kwargs):
-        return await self.__client.create_subscription(
+    def delay(self, **kwargs):
+        return async_to_sync(self.__client.create_subscription)(
             topic_id=self.topic_name,
             subscription_id=self.subscription_name,
             push_to_url=self.url(),
@@ -119,27 +118,27 @@ class SubscriberTask(PubSubTaskMixin, Task, ABC):
 
 
 class PublisherTask(Task, ABC):
-    use_async_publish = False
+    publish_immediately = False
 
-    def run(self, topic_name: str, message: Dict, attributes: Dict = None):
+    def run(self, topic_name: str, message: Dict, attributes: Dict[str, str] = None):
         return async_to_sync(self.__client.publish)(
             message=json.dumps(message),
             topic_id=topic_name,
             attributes=attributes,
         )
 
-    async def delay(self, topic_name: str, message: Dict, attributes: Dict = None):
-        if self.use_async_publish:
+    def delay(self, topic_name: str, message: Dict, attributes: Dict[str, str] = None):
+        if self.publish_immediately:
             # perform asynchronous publish to PubSub, with overhead in:
             # - publishing the message as Task
             # - receiving it through the endpoint
             # - and the finally publishing to PubSub
             # might be useful to use the Cloud Task throttling
             return super().delay(topic_name=topic_name, message=message, attributes=attributes)
-        return await self.run(topic_name=topic_name, message=message, attributes=attributes)
+        return self.run(topic_name=topic_name, message=message, attributes=attributes)
 
-    async def initialize(self, topic_name):
-        await self.__client.create_topic(
+    def initialize(self, topic_name):
+        async_to_sync(self.__client.create_topic)(
             topic_id=topic_name,
         )
 
